==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/module/thorin.pl <==
#============================================================================================================
#
#	o͊ǗW[(THORIN)
#	thorin.pl
#	---------------------------------------------
#	2002.12.05 start
#
#============================================================================================================
package	THORIN;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my (@BUFF, $obj);
	
	$obj = {				# thorinIuWFNg
		'BUFF'	=> \@BUFF,	# o̓obt@
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	obt@o - Print
#	-------------------------------------------
#	@F$line : o̓eLXg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Print
{
	my $this = shift;
	my ($line) = @_;
	
	push @{$this->{'BUFF'}}, $line;
}

#------------------------------------------------------------------------------------------------------------
#
#	INPUT^Oo - HTMLInput
#	-------------------------------------------
#	@F$kind  : ^Cv
#			$name  : O
#			$value : l
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub HTMLInput
{
	my $this = shift;
	my ($kind, $name, $value) = @_;
	my $line;
	
	$line = "<input type=$kind name=\"$name\" value=\"$value\">\n";
	
	push @{$this->{'BUFF'}}, $line;
}

#------------------------------------------------------------------------------------------------------------
#
#	obt@tbV - Flush
#	-------------------------------------------
#	@F$flag       : o̓tO
#			$perm		: p[~bV
#			$szFilePath : o̓pX
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Flush
{
	my $this = shift;
	my ($flag, $perm, $szFilePath) = @_;
	
	# t@C֏o
	if ($flag) {
#		eval
		{
			open OUTPUT, "> $szFilePath";
			flock OUTPUT, 2;
			#truncate OUTPUT, 0;
			#seek OUTPUT, 0, 0;
			print OUTPUT @{$this->{'BUFF'}};
			close OUTPUT;
			chmod $perm, $szFilePath;
		};
	}
	# Wo͂ɏo
	else {
		print @{$this->{'BUFF'}};
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	obt@NA - Clear
#	-------------------------------------------
#	@FȂ
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Clear
{
	my $this = shift;
	
	undef @{$this->{'BUFF'}};
}

#------------------------------------------------------------------------------------------------------------
#
#	}[W - Merge
#	-------------------------------------------
#	@F$thorin : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Merge
{
	my $this = shift;
	my ($thorin) = @_;
	
	foreach (@{$thorin->{'BUFF'}}) {
		push @{$this->{'BUFF'}}, $_;
	}
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;

==> zerochplus_0.7.2.tar.gz: zerochplus_0.7.2/test/module/thorin.pl <==
#============================================================================================================
#
#	o͊ǗW[
#
#============================================================================================================
package	THORIN;

use strict;
#use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $class = shift;
	
	my $obj = {
		'BUFF'	=> [],
	};
	bless $obj, $class;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	obt@o - Print
#	-------------------------------------------
#	@F$line : o̓eLXg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Print
{
	my $this = shift;
	my ($line) = @_;
	
	push @{$this->{'BUFF'}}, $line;
}

#------------------------------------------------------------------------------------------------------------
#
#	INPUT^Oo - HTMLInput
#	-------------------------------------------
#	@F$kind  : ^Cv
#			$name  : O
#			$value : l
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub HTMLInput
{
	my $this = shift;
	my ($kind, $name, $value) = @_;
	
	my $line = "<input type=$kind name=\"$name\" value=\"$value\">\n";
	
	push @{$this->{'BUFF'}}, $line;
}

#------------------------------------------------------------------------------------------------------------
#
#	obt@tbV - Flush
#	-------------------------------------------
#	@F$flag       : o̓tO
#			$perm		: p[~bV
#			$szFilePath : o̓pX
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Flush
{
	my $this = shift;
	my ($flag, $perm, $path) = @_;
	
	# t@C֏o
	if ($flag) {
		if (open(my $fh, (-f $path ? '+<' : '>'), $path)) {
			flock($fh, 2);
			seek($fh, 0, 0);
			print $fh @{$this->{'BUFF'}};
			truncate($fh, tell($fh));
			close($fh);
		}
		chmod($perm, $path);
	}
	# Wo͂ɏo
	else {
		print @{$this->{'BUFF'}};
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	obt@NA - Clear
#	-------------------------------------------
#	@FȂ
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Clear
{
	my $this = shift;
	
	$this->{'BUFF'} = [];
}

#------------------------------------------------------------------------------------------------------------
#
#	}[W - Merge
#	-------------------------------------------
#	@F$thorin : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Merge
{
	my $this = shift;
	my ($thorin) = @_;
	
	push @{$this->{'BUFF'}}, @{$thorin->{'BUFF'}};
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;
